<?php
/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2010 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package InterWorx
 * @author  Paul Oehler <poehler@interworx.com>
 * @date    Sep 27, 2009
 */

/**
 * Send Usage Stats Plugin.
 *
 * @package    InterWorx
 * @subpackage Plugin
 */
class Plugin_SendUsageStats extends Plugin {

  /**
   * Process edit form.
   *
   * @param Form_NW_Plugins_Edit $Form
   */
  public function processMyEditForm( Form_NW_Plugins_Edit $Form ) {
    if( $Form->getValue( 'status' ) == 1 ) {
      $this->_initLoggingTablesIfNecessary();
    }
  }

  /**
   *  init logging tables if needed.
   */
  private function _initLoggingTablesIfNecessary() {
    $db     = IW::DB();
    $sql    = 'SHOW TABLES';
    $tables = IWorxDbUtil::db_getCol( $db, $sql );

    if( in_array( 'logged_events', $tables ) === false ) {
      $sql = 'CREATE TABLE IF NOT EXISTS `logged_events` (
  `event_id` int(11) NOT NULL auto_increment,
  `event_date` int(11) NOT NULL default \'0\',
  `description` text NOT NULL,
  `user_id` int(11) NOT NULL default \'0\',
  `module_id` int(11) unsigned NOT NULL default \'0\',
  `ip` varchar(15) NOT NULL default \'\',
  `module` enum(\'nodeworx\',\'siteworx\',\'reseller\',\'null\')
           NOT NULL default \'nodeworx\',
  `class` varchar(64) NOT NULL default \'\',
  `action` varchar(64) NOT NULL default \'\',
  `environment` varchar(15) NOT NULL default \'\',
  `session` varchar(50) NOT NULL default \'\',
  PRIMARY KEY  (`event_id`)
) TYPE=MyISAM';
      IWorxDbUtil::db_query( $db, $sql );
    }

  }

  /**
   * Pre action.
   *
   * @param string        $ctrl_act
   * @param Ctrl_Abstract $Ctrl
   * @param string        $action
   * @param mixed         $params
   */
  public function preAction( $ctrl_act, Ctrl_Abstract $Ctrl, $action, $params ) {
    list( $ctrl, $act ) = explode( ':', $ctrl_act );
    if( $ctrl === 'Ctrl_Xhr' ) {
      return;
    }
    try {
      $this->_logPreAction( $ctrl, $act, $Ctrl, $params );
    } catch( Exception $e ) {
      IWorx_Exception::logAnother( $e );
    }
  }

  /**
   * Log pre action.
   *
   * @param string        $ctrl
   * @param string        $action
   * @param Ctrl_Abstract $Ctrl
   * @param mixed         $params
   */
  private function _logPreAction( $ctrl, $action, Ctrl_Abstract $Ctrl, $params ) {
    $db = IW::DB();

    $IW = IW::Env()->getActiveSession()->getInterWorx();

    if( $IW instanceof NodeWorx ) {
      if( $IW->isReseller() ) {
        $module = 'reseller';
      } else {
        $module = 'nodeworx';
      }
    } else if( $IW instanceof SiteWorx ) {
      $module = 'siteworx';
    } else {
      $module = 'null';
    }

    $q_date        = q( microtime( true ) );
    $q_description = q( 'PRE-ACTION' );
    $q_user_id     = q( IW::Env()->getActiveSession()->getUserId() );
    $q_module_id   = q( IW::Env()->getActiveSession()->getInterWorx()->getId() );
    $q_ip          = q( $_SERVER['REMOTE_ADDR'] );
    $q_env         = q( IW::Env()->getUserInterfaceTypeString() );
    $q_session     = q( crypt( session_id(), '$1$obfuschiz' ) );
    $q_ctrl        = q( $ctrl );
    $q_action      = q( $action );
    $q_module      = q( $module );

    $sql = "INSERT INTO logged_events
            (event_date, description, user_id, module_id, ip, module, class,
             action, environment, session )
            VALUES
            ({$q_date}, {$q_description}, {$q_user_id}, {$q_module_id},
             {$q_ip}, {$q_module}, {$q_ctrl}, {$q_action}, {$q_env},
             {$q_session})";

    IWorxDbUtil::db_query( $db, $sql );
  }

  /**
   * Post action.
   *
   * @param string        $ctrl_act
   * @param Ctrl_Abstract $Ctrl
   * @param string        $action
   * @param mixed         $params
   */
  public function postAction( $ctrl_act, Ctrl_Abstract $Ctrl, $action, $params ) {
    list( $ctrl, $act ) = explode( ':', $ctrl_act );
    try {
      $this->_logPostAction( $ctrl, $act, $Ctrl, $params );
    } catch( Exception $e ) {
      IWorx_Exception::logAnother( $e );
    }
  }

  /**
   * Log post action.
   *
   * @param string        $ctrl
   * @param string        $action
   * @param Ctrl_Abstract $Ctrl
   * @param mixed         $params
   */
  private function _logPostAction( $ctrl, $action, Ctrl_Abstract $Ctrl, $params ) {
    $db = IW::DB();

    $IW = IW::Env()->getActiveSession()->getInterWorx();

    if( $IW instanceof NodeWorx ) {
      if( $IW->isReseller() ) {
        $module = 'reseller';
      } else {
        $module = 'nodeworx';
      }
    } else if( $IW instanceof SiteWorx ) {
      $module = 'siteworx';
    } else {
      $module = 'null';
    }

    $template = $Ctrl->getView()->getTemplate();

    $q_date        = q( microtime( true ) );
    $q_description = q( 'POST-ACTION: ' . $template );
    $q_user_id     = q( IW::Env()->getActiveSession()->getUserId() );
    $q_module_id   = q( IW::Env()->getActiveSession()->getInterWorx()->getId() );
    $q_ip          = q( $_SERVER['REMOTE_ADDR'] );
    $q_env         = q( IW::Env()->getUserInterfaceTypeString() );
    $q_session     = q( crypt( session_id(), '$1$obfuschiz' ) );
    $q_ctrl        = q( $ctrl );
    $q_action      = q( $action );
    $q_module      = q( $module );

    $sql = "INSERT INTO logged_events
            (event_date, description, user_id, module_id, ip, module, class,
             action, environment, session )
            VALUES
            ({$q_date}, {$q_description}, {$q_user_id}, {$q_module_id},
             {$q_ip}, {$q_module}, {$q_ctrl}, {$q_action}, {$q_env},
             {$q_session})";

    IWorxDbUtil::db_query( $db, $sql );
  }

  /**
   * Handle error.
   *
   * @param integer $num
   * @param string  $message
   * @param string  $file
   * @param integer $line
   * @param array   $trace
   */
  public function handleError( $num, $message, $file, $line, array $trace ) {
    $db = IW::DB();

    $trace = implode( "\n", $trace );

    $q_date        = q( microtime( true ) );
    $q_description = q( "ERROR: {$message}\n{$trace}\n" );

    $q_user_id     = q( '' );
    $q_module_id   = q( '' );
    $q_ip          = q( $_SERVER['REMOTE_ADDR'] );
    $q_env         = q( IW::Env()->getUserInterfaceTypeString() );
    $q_session     = q( '' );
    $q_ctrl        = q( '' );
    $q_action      = q( '' );
    $q_module      = q( '' );

    $sql = "INSERT INTO logged_events
            (event_date, description, user_id, module_id, ip, module, class,
             action, environment, session )
            VALUES
            ({$q_date}, {$q_description}, {$q_user_id}, {$q_module_id},
             {$q_ip}, {$q_module}, {$q_ctrl}, {$q_action}, {$q_env},
             {$q_session})";

    IWorxDbUtil::db_query( $db, $sql );
  }

  /**
   *  TODO: actually send the data somewhere, somehow.
   */
  public function sendUsageData() {
    $db = IW::DB();

    $sql = 'DELETE FROM logged_events';
    IWorxDbUtil::db_query( $db, $sql );
  }

}
