<?php
/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2010 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package InterWorx
 * @author  Paul Oehler <poehler@interworx.com>
 * @date    Sep 24, 2009
 */

/**
 * Simplescripts config form.
 *
 * @package    InterWorx
 * @subpackage Form
 */
class Form_NW_Simplescripts_Config extends Form {

  /**
   * Initialize.
   */
  protected function _initialize() {
    parent::_initialize( 'simplescripts_config', 'Simple Scripts Config' );

    $nw_id = IW::NW()->getId();

    $Plugin = IW::PluginManager()->getPlugin( 'simplescripts' );

    $host_key = $Plugin->getDatastoreVar( "host_key:{$nw_id}" );
    $this->addInput( new Input_String( 'host_key', $host_key ) )
      ->setLabel( 'Host Key' )
      ->setRequired( false );

    $host_api_key = $Plugin->getDatastoreVar( "host_api_key:{$nw_id}" );
    $this->addInput( new Input_Password( 'host_api_key', $host_api_key ) )
      ->setLabel( 'Host API Key' )
      ->setRequired( false );

    if( IW::NW()->isReseller() === false ) {
      $use_main = 'Let resellers use this simple scripts account';
      $use_own  = 'Let resellers use their own simple scripts account';
      $rslopts  = array( 'use_main' => $use_main,
                         'use_own'  => $use_own );
      $reseller_config = $Plugin->getDatastoreVar( 'reseller_config' );
      if( $reseller_config === '' ) {
        $reseller_config = 'use_own';
      }
      $this->addInput( new Input_Set( 'reseller_config', $reseller_config ) )
        ->setLabel( 'Reseller configuration' )
        ->setDataSource( new DataSource_ArrayAssoc( $rslopts ) );
    }

    $msg  = 'You can customize your customer\'s interaction with SimpleScripts ';
    $msg .= 'by creating your own web host account.  More information is ';
    $msg .= 'available at <br/><a target="_blank" href="http://www.simplescripts.com/host/activate">http://www.simplescripts.com/host/activate</a>';
    $this->setDescription( $msg );
    $this->setCancelDisplay( false );
  }
}
